The Administrative Appeals Chamber is responsible for dealing with appeals against decisions made by certain lower tribunals and organisations including social security and child support; war pensions and armed forces compensation; mental health; special education needs or disabilities; disputes heard by the General Regulatory Chamber; decisions made by the Disclosure and Barring Service; decisions made by the Traffic Commissioner (or the Transport Regulation Unit in Northern Ireland); Special Education Needs Tribunal for Wales; Mental Health Review Tribunal for Wales and Pensions Appeal Tribunal in Northern Ireland (only for assessment appeals under the War Pensions Scheme).

They also handle applications for judicial review of decisions made by First-Tier Tribunal (Criminal Injuries Compensation) and other first-tier tribunals where there is no right of appeal.

This tribunal began to regularly transfer decisions to The National Archives in 2022. The oldest decision from this tribunal included in Find Case Law is from {start_year}.

You can read more about it on the Administrative Appeals Chamber on the [HM Courts and Tribunals Service website](https://www.gov.uk/courts-tribunals/upper-tribunal-administrative-appeals-chamber){target="\_blank"}.
